﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.IO;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

public partial class AdminEditImageMap : System.Web.UI.Page
{
    /// <summary>
    /// This method handles the page initialization event
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Init(object sender, EventArgs e)
    {
        // Load image maps
        LoadImageMaps();

    } // End of the Page_Init method

    /// <summary>
    /// This method handles the page load event
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        // Make sure that the pageload not is a post back
        if (Page.IsPostBack == false)
        {
            // Get all the categories
            List<ImageMapCategory> categories = ImageMapCategory.GetAll();

            // Loop and load all the categories
            for (int i = 0; i < categories.Count; i++)
            {
                this.annytabImapSelectCategory.Items.Add(new ListItem(categories[i].name, categories[i].id.ToString()));
            }

            // Get all the products
            List<Product> products = Product.GetAll();

            // Loop and load all the products
            for (int i = 0; i < products.Count; i++)
            {
                // Add the product to the select control
                this.annytabImapSelectProduct.Items.Add(new ListItem(products[i].name, products[i].id.ToString()));
            }

        } // End of if (Page.IsPostBack == false)

    } // End of the Page_Load method

    /// <summary>
    /// Load image maps
    /// </summary>
    private void LoadImageMaps()
    {
        // Get all the image maps
        List<ImageMap> imageMaps = ImageMap.GetAll();

        // Create the select image maps control
        for (int i = 0; i < imageMaps.Count; i++)
        {
            // Create the file path
            string filePath = Server.MapPath(imageMaps[i].image_url);

            // Check if the file exists
            if (File.Exists(filePath) == false)
                continue;

            // Get the width and height for the image
            System.Drawing.Image image = System.Drawing.Image.FromFile(filePath);

            // imageId, imageUrl, width, height | categoryId | Product id, product name, product price, 
            string hiddenProductData = imageMaps[i].id + "," + imageMaps[i].image_url + "," + image.Size.Width
                + "px," + image.Size.Height + "px|" + imageMaps[i].category_id + "|";

            // Dispose the image
            image.Dispose();

            // Get the map points
            string[] mapPoints = imageMaps[i].image_map_points.Split(';');

            // Loop image points
            for (int j = 0; j < mapPoints.Length; j++)
            {
                if (mapPoints[j] == "")
                    continue;

                // Get the map point data
                string[] mapPointData = mapPoints[j].Split(',');

                // Get the product
                Product product = Product.GetOneById(Convert.ToInt32(mapPointData[0]));

                // Add information about the point to the hidden data field
                hiddenProductData += product.id + "," + product.name + "," + mapPointData[1] + "," + mapPointData[2];

                if (j != (mapPoints.Length - 1))
                    hiddenProductData += ";";
            }

            // Create the div control
            HtmlGenericControl div = new HtmlGenericControl("div");
            div.Attributes["data-points"] = hiddenProductData;
            div.Attributes["class"] = "annytab-imap-imagemap-button";
            div.Style["background-image"] = "url('" + imageMaps[i].image_url + "')";

            // Create the image delete button
            ImageButton deleteImage = new ImageButton();
            deleteImage.AlternateText = "Delete image map";
            deleteImage.ToolTip = "Delete image map";
            deleteImage.ImageUrl = "images/blackCross.png";
            deleteImage.Attributes["image-id"] = imageMaps[i].id.ToString();
            deleteImage.Attributes["image-url"] = imageMaps[i].image_url.ToString();
            deleteImage.Click += new ImageClickEventHandler(this.DeleteImageMap);
            deleteImage.Style["position"] = "absolute";
            deleteImage.Style["width"] = "20px";
            deleteImage.Style["height"] = "20px";
            deleteImage.Style["top"] = "-5px";
            deleteImage.Style["right"] = "-5px";
            deleteImage.Style["cursor"] = "pointer";

            // Add the image to the div
            div.Controls.Add(deleteImage);

            // Add the div to the image container
            this.annytabImapImageContainer.Controls.Add(div);
        }

    } // End of the LoadImageMaps method

    /// <summary>
    /// Delete the image map
    /// </summary>
    /// <param name="sender">A reference to the control that caused the event</param>
    /// <param name="e">Event arguments</param>
    protected void DeleteImageMap(object sender, EventArgs e)
    {
        // Get the image button that caused the event
        ImageButton image = (ImageButton)sender;

        // Get data from the button
        Int32 imageMapId = Convert.ToInt32(image.Attributes["image-id"]);
        string imageUrl = image.Attributes["image-url"];
        string filePath = Server.MapPath(imageUrl);

        // Remove the image
        try
        {
            File.Delete(filePath);
        }
        catch (Exception ex)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + ex.Message + "</div>";
            return;
        }

        // Remove the post in the database
        ImageMap.DeleteOnId(imageMapId);

        // Reload the page
        Response.Redirect("AdminEditImageMap.aspx");

    } // End of the DeleteImageMap method

    /// <summary>
    /// Update the image map and all the points to the database
    /// </summary>
    /// <param name="name"></param>
    /// <param name="imageUrl"></param>
    /// <param name="imagePoints"></param>
    [System.Web.Services.WebMethod]
    public static string UpdateImageMap(string dataString)
    {
        // Split the dataString by |
        string[] mainData = dataString.Split('|'); // image_data, category_id, map_points

        // Get the image map data
        string[] imageMapData = mainData[0].Split(',');

        // Create a new image map
        ImageMap imageMap = new ImageMap();
        imageMap.id = Convert.ToInt32(imageMapData[0]);
        imageMap.image_url = imageMapData[1];
        imageMap.category_id = Convert.ToInt32(mainData[1]);
        imageMap.image_map_points = mainData[2];

        // Update the image map
        ImageMap.Update(imageMap);

        // Redirect the user
        return "success";

    } // End of the SaveImageMap method

    #region Category methods

    /// <summary>
    /// Add a new category
    /// </summary>
    protected void AddNewCategory(object sender, EventArgs e)
    {
        // Get the name
        string name = this.txtCategoryName.Text;

        // Make sure that a name has been entered
        if (name != string.Empty)
        {
            // Add the new category
            ImageMapCategory category = new ImageMapCategory();
            category.name = name;
            ImageMapCategory.Add(category);

            // Reload the page
            Response.Redirect("AdminEditImageMap.aspx");
        }
        else
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not entered a name for the category!" + "</div>";
            return;
        }

    } // End of the AddNewCategory method

    /// <summary>
    /// Update the selected category
    /// </summary>
    protected void UpdateCategory(object sender, EventArgs e)
    {
        // Get the selected category
        Int32 id = Convert.ToInt32(this.annytabImapSelectCategory.SelectedValue);

        // Get the new name
        string name = this.txtCategoryName.Text;

        if (id < 0)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not selected a category!" + "</div>";
            return;
        }
        else if (name == string.Empty)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not entered the new category name!" + "</div>";
            return;
        }
        else
        {
            // Create a new category
            ImageMapCategory category = new ImageMapCategory();
            category.id = id;
            category.name = name;

            // Update the category
            ImageMapCategory.Update(category);

            // Reload the page
            Response.Redirect("AdminEditImageMap.aspx");
        }

    } // End of the EditCategory method

    /// <summary>
    /// Delete the selected category
    /// </summary>
    protected void DeleteCategory(object sender, EventArgs e)
    {
        // Get the selected category
        Int32 id = Convert.ToInt32(this.annytabImapSelectCategory.SelectedValue);

        if (id < 0)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not selected a category!" + "</div>";
            return;
        }
        else
        {
            // Delete the category
            ImageMapCategory.DeleteOnId(id);

            // Reload the page
            Response.Redirect("AdminEditImageMap.aspx");
        }

    } // End of the DeleteCategory method

    #endregion

} // End of the class