﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.IO;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

public partial class AdminNewImageMap : System.Web.UI.Page
{
    /// <summary>
    /// This method handles the page initialization event
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Init(object sender, EventArgs e)
    {
        // Load images
        LoadImages();

    } // End of the Page_Init method

    /// <summary>
    /// This method handles the page load event
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        // Make sure that the page load not is a postback
        if (Page.IsPostBack == false)
        {
            // Get all the categories
            List<ImageMapCategory> categories = ImageMapCategory.GetAll();

            // Loop and load all the categories
            for (int i = 0; i < categories.Count; i++)
            {
                this.annytabImapSelectCategory.Items.Add(new ListItem(categories[i].name, categories[i].id.ToString()));
            }

            // Get all the products
            List<Product> products = Product.GetAll();

            // Loop and load all the products
            for (int i = 0; i < products.Count; i++)
            {
                // Add the product to the select control
                this.annytabImapSelectProduct.Items.Add(new ListItem(products[i].name, products[i].id.ToString()));
            }

        } // End of if (Page.IsPostBack == false)

    } // End of the Page_Load method

    /// <summary>
    /// Add a new image map
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void AddNewImageMap(object sender, EventArgs e)
    {
        // Giv a error message if the posted file is null
        if (this.fileUploadImage.PostedFile.FileName == "")
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- You have not selected an image file!</div>";
            return;
        }

        // Get the filepath
        string filePath = "images/image_maps/" + this.fileUploadImage.PostedFile.FileName;
        string serverFilePath = Server.MapPath(filePath);

        // Save the image file
        try
        {
            this.fileUploadImage.PostedFile.SaveAs(serverFilePath);
        }
        catch (Exception ex)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + ex.Message + "</div>";
            return;
        }

        // Reload the page
        Response.Redirect("AdminNewImageMap.aspx");

    } // End of the AddNewImageMap method

    /// <summary>
    /// Save the image map and all the points to the database
    /// </summary>
    /// <param name="name"></param>
    /// <param name="imageUrl"></param>
    /// <param name="imagePoints"></param>
    [System.Web.Services.WebMethod]
    public static string SaveImageMap(string dataString)
    {
        // Split the dataString by |
        string[] mainData = dataString.Split('|');

        // Create a new image map
        ImageMap imageMap = new ImageMap();
        imageMap.image_url = mainData[0];
        imageMap.category_id = Convert.ToInt32(mainData[1]);
        imageMap.image_map_points = mainData[2];

        // Add the image map
        long insertId = ImageMap.Add(imageMap);

        // Redirect the user
        return "success";

    } // End of the SaveImageMap method

    /// <summary>
    /// Load images from the image maps directory
    /// </summary>
    private void LoadImages()
    {
        // Create the filepath
        string filePath = Server.MapPath("images/image_maps/");

        // Create a list with files and an array with extensions
        List<string> files = new List<string>();
        string[] extensions = new string[] { "*.jpg", "*.png", "*.gif" };

        // Get all the images in the image maps folder
        for (int i = 0; i < extensions.Length; i++)
        {
            // Get all the files with a certain extension
            string[] fileNames = Directory.GetFiles(filePath, extensions[i]);

            // Loop each file in the string array
            foreach (string file in fileNames)
            {
                // Get the filename
                string fileName = "images/image_maps/" + Path.GetFileName(file);

                // Get the width and height for the image
                System.Drawing.Image image = System.Drawing.Image.FromFile(file);

                // Get the image url, width, height 
                string fileData = fileName + "," + image.Size.Width + "px," + image.Size.Height + "px";

                // Dispose of the image
                image.Dispose();

                // Add the file data
                files.Add(fileData);
            }
        }
        
        // Loop the filedata and create image map buttons
        for (int i = 0; i < files.Count; i++)
        {
            // Get the file name
            string[] fileData = files[i].Split(',');

            // Create the div control
            HtmlGenericControl div = new HtmlGenericControl("div");
            div.Attributes["data-file"] = files[i];
            div.Attributes["class"] = "annytab-imap-imagemap-button";
            div.Style["background-image"] = "url('" + fileData[0] + "')";

            // Create the image button
            ImageButton image = new ImageButton();
            image.AlternateText = "Delete image";
            image.ToolTip = "Delete image";
            image.ImageUrl = "images/blackCross.png";
            image.Attributes["image-url"] = fileData[0];
            image.Click += new ImageClickEventHandler(this.RemoveImage);
            image.Style["position"] = "absolute";
            image.Style["width"] = "20px";
            image.Style["height"] = "20px";
            image.Style["top"] = "-5px";
            image.Style["right"] = "-5px";
            image.Style["cursor"] = "pointer";

            // Add the image to the div
            div.Controls.Add(image);

            // Add the div to the image container
            this.annytabImapImageContainer.Controls.Add(div);
        }

    } // End of the LoadImages method

    /// <summary>
    /// This method will remove the current image
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void RemoveImage(object sender, EventArgs e)
    {
        // Get the image button that caused the event
        ImageButton image = (ImageButton)sender;

        // Get the image url
        string imageUrl = image.Attributes["image-url"];
        string filePath = Server.MapPath(imageUrl);

        // Remove the image
        try
        {
            File.Delete(filePath);
        }
        catch (Exception ex)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + ex.Message + "</div>";
            return;
        }

        // Reload the page
        Response.Redirect("AdminNewImageMap.aspx");

    } // End of the RemoveImage method

    #region Category methods

    /// <summary>
    /// Add a new category
    /// </summary>
    protected void AddNewCategory(object sender, EventArgs e)
    {
        // Get the name
        string name = this.txtCategoryName.Text;

        // Make sure that a name has been entered
        if (name != string.Empty)
        {
            // Add the new category
            ImageMapCategory category = new ImageMapCategory();
            category.name = name;
            ImageMapCategory.Add(category);

            // Reload the page
            Response.Redirect("AdminNewImageMap.aspx");
        }
        else
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not entered a name for the category!" + "</div>";
            return;
        }

    } // End of the AddNewCategory method

    /// <summary>
    /// Update the selected category
    /// </summary>
    protected void UpdateCategory(object sender, EventArgs e)
    {
        // Get the selected category
        Int32 id = Convert.ToInt32(this.annytabImapSelectCategory.SelectedValue);

        // Get the new name
        string name = this.txtCategoryName.Text;

        if (id < 0)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not selected a category!" + "</div>";
            return;
        }
        else if (name == string.Empty)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not entered a new name for the category!" + "</div>";
            return;
        }
        else
        {
            // Create a new category
            ImageMapCategory category = new ImageMapCategory();
            category.id = id;
            category.name = name;

            // Update the category
            ImageMapCategory.Update(category);

            // Reload the page
            Response.Redirect("AdminNewImageMap.aspx");
        }

    } // End of the EditCategory method

    /// <summary>
    /// Delete the selected category
    /// </summary>
    protected void DeleteCategory(object sender, EventArgs e)
    {
        // Get the selected category
        Int32 id = Convert.ToInt32(this.annytabImapSelectCategory.SelectedValue);

        if (id < 0)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"annytab-imap-admin-title\">Information</div>";
            this.divErrors.InnerHtml += "<div class=\"annytab-imap-error-message\" style=\"color:#ff0000;\">- " + "You have not selected a category!" + "</div>";
            return;
        }
        else
        {
            // Delete the category
            ImageMapCategory.DeleteOnId(id);

            // Reload the page
            Response.Redirect("AdminNewImageMap.aspx");
        }

    } // End of the DeleteCategory method

    #endregion

} // End of the class