﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

public partial class AdminSpinningImages : System.Web.UI.Page
{
    /// <summary>
    /// This method handles the page load event
    /// </summary>
    /// <param name="sender">A reference to the sender control</param>
    /// <param name="e">Event arguments</param>
    protected void Page_Load(object sender, EventArgs e)
    {
        // Make sure that the page load not is a postback
        if (Page.IsPostBack == false)
        {
            // Get all the products
            List<Product> products = Product.GetAll();

            // Loop and load all the products
            for (int i = 0; i < products.Count; i++)
            {
                // Try to get the spin image
                SpinningImage spinningImage = SpinningImage.GetOneById(products[i].id);

                // Add the product to the select control
                this.ddlSelectProduct.Items.Add(new ListItem(products[i].name, products[i].id.ToString()));

                // Add a red color to the text if it exists
                if (spinningImage != null)
                    this.ddlSelectProduct.Items[this.ddlSelectProduct.Items.Count - 1].Attributes.Add("style", "color:#ff0000");
            }

        } // End of if (Page.IsPostBack == false)
        else
        {
            // Loop all the options in the select
            for (int i = 0; i < this.ddlSelectProduct.Items.Count; i++)
            {
                // Get the id
                Int32 id = Convert.ToInt32(this.ddlSelectProduct.Items[i].Value);

                // Try to get the spin image
                SpinningImage spinningImage = SpinningImage.GetOneById(id);

                // Add a red color to the text if it exists
                if (spinningImage != null)
                    this.ddlSelectProduct.Items[i].Attributes.Add("style", "color:#ff0000");
            }
        }

    } // End of the Page_Load method

    /// <summary>
    /// Create a spinning image
    /// </summary>
    /// <param name="sender">A reference to the sender control</param>
    /// <param name="e">Event arguments</param>
    protected void CreateSpinningImage(object sender, EventArgs e)
    {
        // Get the selected product id
        Int32 selectedProductId = Convert.ToInt32(this.ddlSelectProduct.SelectedValue);

        // Check if a product has been selected
        if (selectedProductId < 0)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"errorMessage\" style=\"color:#ff0000;\">- Du har inte valt en produkt!</div>";
            return;
        }

        // Get the spinning image
        SpinningImage spinImage = SpinningImage.GetOneById(selectedProductId);

        // Check if a spinning image already has been created
        if (spinImage != null)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"errorMessage\" style=\"color:#ff0000;\">- Det finns redan en bildanimation för denna produkt!</div>";
            return;
        }

        // Get posted files
        HttpFileCollection files = Request.Files;

        // Check if one or more files have been selected
        if (files.Count < 2)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"errorMessage\" style=\"color:#ff0000;\">- Du måste välja minst en fil!</div>";
            return;
        }

        // Set the directory name
        string directoryName = "images/spinning_images/" + selectedProductId.ToString() + "/";
        string directoryPath = Server.MapPath(directoryName);

        // Create the directory if it does not exist
        if (Directory.Exists(directoryPath) == false)
        {
            Directory.CreateDirectory(directoryPath);
        }

        // Get all the files and save them to the server
        for (int i = 0; i < files.Count; i++)
        {
            // Get the file
            HttpPostedFile file = files[i];

            if (file.ContentLength == 0)
                continue;

            // Save the file
            file.SaveAs(Server.MapPath(directoryName + file.FileName));
        }

        // Save the spinning image to the database
        if (SpinningImage.GetOneById(selectedProductId) == null)
        {
            SpinningImage image = new SpinningImage();
            image.product_id = selectedProductId;
            SpinningImage.Add(image);
        }

        // Redirect the user
        Response.Redirect("AdminSpinningImages.aspx");

    } // End of the CreateSpinningImage method

    /// <summary>
    /// Delete a spinning image
    /// </summary>
    /// <param name="sender">A reference to the sender control</param>
    /// <param name="e">Event arguments</param>
    protected void DeleteSpinningImage(object sender, EventArgs e)
    {
        // Get the selected product id
        Int32 selectedProductId = Convert.ToInt32(this.ddlSelectProduct.SelectedValue);

        // Check if a product has been selected
        if (selectedProductId < 0)
        {
            this.divErrors.Style["display"] = "inline-block";
            this.divErrors.InnerHtml = "<div class=\"errorMessage\" style=\"color:#ff0000;\">- Du har inte valt en produkt!</div>";
            return;
        }

        // Set the directory name
        string directoryName = "images/spinning_images/" + selectedProductId.ToString() + "/";
        string directoryPath = Server.MapPath(directoryName);

        // Get all the files in the directory
        if (Directory.Exists(directoryPath) == true)
        {
            string[] files = Directory.GetFiles(directoryPath);

            // Remove all of the files in the directory
            for (int i = 0; i < files.Length; i++)
            {
                File.Delete(files[i]);
            }

            // Remove the directory
            Directory.Delete(directoryPath);
        }

        // Delete the spinning image in the database
        SpinningImage.DeleteOnId(selectedProductId);

        // Redirect the user
        Response.Redirect("AdminSpinningImages.aspx");

    } // End of the DeleteSpinnningImage method

} // End of the class