﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Configuration;
using MySql.Data;
using MySql.Data.MySqlClient;

/// <summary>
/// Summary description for ImageMap
/// </summary>
public class ImageMap
{
    #region Variables

    public int id;
    public string image_url;
    public string image_map_points;
    public int category_id;

    #endregion

    #region Constructors

    /// <summary>
    /// Create a new image map with default properties
    /// </summary>
    public ImageMap()
    {
        // Set values for instance variables
        this.id = 0;
        this.image_url = "Unknown";
        this.image_map_points = "Unknown";
        this.category_id = 0;

    } // End of the constructor

    /// <summary>
    /// Create a new image map from a reader
    /// </summary>
    /// <param name="reader">A reference to a reader</param>
    public ImageMap(MySqlDataReader reader)
    {
        // Set values for instance variables
        this.id = Convert.ToInt32(reader["id"]);
        this.image_url = reader["image_url"].ToString();
        this.image_map_points = reader["image_map_points"].ToString();
        this.category_id = Convert.ToInt32(reader["category_id"]);

    } // End of the constructor

    #endregion

    #region Insert methods

    /// <summary>
    /// Add one image map
    /// </summary>
    /// <param name="post">A reference to a image map</param>
    public static long Add(ImageMap post)
    {
        // Create the long to return
        long idOfInsert = 0;

        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "INSERT INTO image_maps (image_url, image_map_points, category_id) "
            + "VALUES (@image_url, @image_map_points, @category_id)";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {

                // Add parameters
                cmd.Parameters.AddWithValue("@image_url", post.image_url);
                cmd.Parameters.AddWithValue("@image_map_points", post.image_map_points);
                cmd.Parameters.AddWithValue("@category_id", post.category_id);

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases
                try
                {
                    // Open the connection
                    cn.Open();

                    // Execute the insert
                    cmd.ExecuteNonQuery();
                    idOfInsert = cmd.LastInsertedId;

                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
            }
        }

        // Return the id of the inserted item
        return idOfInsert;

    } // End of the Add method

    #endregion

    #region Update methods
    
    /// <summary>
    /// Update a image map post
    /// </summary>
    /// <param name="post">A reference to a image map post</param>
    public static void Update(ImageMap post)
    {
        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "UPDATE image_maps SET image_url = @image_url, image_map_points = @image_map_points, "
            + "category_id = @category_id WHERE id = @id";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Add parameters
                cmd.Parameters.AddWithValue("@id", post.id);
                cmd.Parameters.AddWithValue("@image_url", post.image_url);
                cmd.Parameters.AddWithValue("@image_map_points", post.image_map_points);
                cmd.Parameters.AddWithValue("@category_id", post.category_id);

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Execute the update
                    cmd.ExecuteNonQuery();

                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
            }
        }

    } // End of the Update method

    #endregion

    #region Get methods

    /// <summary>
    /// Get a list of all image maps
    /// </summary>
    /// <returns>A list of image map posts</returns>
    public static List<ImageMap> GetAll()
    {
        // Create the list to return
        List<ImageMap> posts = new List<ImageMap>();

        // Create the connection string and the sql statement. Limit with two arguments, 
        // the first argument specifies the offset of the first row to return, and the second specifies the 
        // maximum number of rows to return. The offset of the initial row is 0 (not 1).
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT * FROM image_maps ORDER BY id ASC";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The using block is used to call dispose automatically even if there is a exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Create a MySqlDataReader
                MySqlDataReader reader = null;

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Fill the reader with data from the select command.
                    reader = cmd.ExecuteReader();

                    // Loop through the reader as long as there is something to read.
                    while (reader.Read())
                    {
                        posts.Add(new ImageMap(reader));
                    }
                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
                finally
                {
                    // Call Close when done reading to avoid memory leakage.
                    if (reader != null)
                        reader.Close();
                }
            }
        }

        // Return the list of posts
        return posts;

    } // End of the GetAll method

    /// <summary>
    /// Get one image map on id
    /// </summary>
    /// <param name="id">A id</param>
    /// <returns>A reference to a image map post</returns>
    public static ImageMap GetOneById(Int32 id)
    {
        // Create the post to return
        ImageMap post = null;

        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT * FROM image_maps WHERE id = @id LIMIT 1";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Add a parameters
                cmd.Parameters.AddWithValue("@id", id);

                // Create a MySqlDataReader
                MySqlDataReader reader = null;

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Fill the reader with one row of data.
                    reader = cmd.ExecuteReader();

                    // Loop through the reader as long as there is something to read and add values
                    while (reader.Read())
                    {
                        post = new ImageMap(reader);
                    }
                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
                finally
                {
                    // Call Close when done reading to avoid memory leakage.
                    if (reader != null)
                        reader.Close();
                }
            }
        }

        // Return the post
        return post;

    } // End of the GetOneById method

    #endregion

    #region Delete methods

    /// <summary>
    /// Delete a image map on id
    /// </summary>
    /// <param name="id">The id number for the template file</param>
    public static void DeleteOnId(int id)
    {
        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "DELETE FROM image_maps WHERE id = @id";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Add parameters
                cmd.Parameters.AddWithValue("@id", id);

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Execute the update
                    cmd.ExecuteNonQuery();

                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
            }
        }

    } // End of the DeleteOnId method

    #endregion

} // End of the class