﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Configuration;
using MySql.Data;
using MySql.Data.MySqlClient;

/// <summary>
/// This class represent a product
/// </summary>
public class Product
{
    #region Variables

    public Int32 id;
    public string name;
    public float price;
    public string image_url;
    public string page_name;

    #endregion

    #region Constructors

    /// <summary>
    /// Create a new product with default properties
    /// </summary>
    public Product()
    {
        // Set values for instance variables
        this.id = 0;
        this.name = "Unknown";
        this.price = 0;
        this.image_url = "Unknown";
        this.page_name = "Unknown";

    } // End of the constructor

    /// <summary>
    /// Create a new product from a reader
    /// </summary>
    /// <param name="reader">A reference to a reader</param>
    public Product(MySqlDataReader reader)
    {
        // Set values for instance variables
        this.id = Convert.ToInt32(reader["id"]);
        this.name = reader["name"].ToString();
        this.price = Convert.ToSingle(reader["price"]);
        this.image_url = reader["image_url"].ToString();
        this.page_name = reader["page_name"].ToString();

    } // End of the constructor

    #endregion

    #region Get methods

    /// <summary>
    /// Get one product on id
    /// </summary>
    /// <param name="id">A id</param>
    /// <returns>A reference to a product</returns>
    public static Product GetOneById(Int32 id)
    {
        // Create the post to return
        Product post = null;

        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT * FROM products WHERE id = @id LIMIT 1";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Add a parameters
                cmd.Parameters.AddWithValue("@id", id);

                // Create a MySqlDataReader
                MySqlDataReader reader = null;

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Fill the reader with one row of data.
                    reader = cmd.ExecuteReader();

                    // Loop through the reader as long as there is something to read and add values
                    while (reader.Read())
                    {
                        post = new Product(reader);
                    }
                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
                finally
                {
                    // Call Close when done reading to avoid memory leakage.
                    if (reader != null)
                        reader.Close();
                }
            }
        }

        // Return the post
        return post;

    } // End of the GetOneById method

    /// <summary>
    /// Get all the products
    /// </summary>
    /// <returns>A reference to a list of products</returns>
    public static List<Product> GetAll()
    {
        // Create the list to return
        List<Product> products = new List<Product>(10);

        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT * FROM products ORDER BY id ASC";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {

                // Create a MySqlDataReader
                MySqlDataReader reader = null;

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Fill the reader with one row of data.
                    reader = cmd.ExecuteReader();

                    // Loop through the reader as long as there is something to read and add values
                    while (reader.Read())
                    {
                        products.Add(new Product(reader));
                    }
                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
                finally
                {
                    // Call Close when done reading to avoid memory leakage.
                    if (reader != null)
                        reader.Close();
                }
            }
        }

        // Return the list
        return products;

    } // End of the GetAll method

    #endregion

} // End of the class