﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Configuration;
using MySql.Data;
using MySql.Data.MySqlClient;

/// <summary>
/// This class represents a spinning image
/// </summary>
public class SpinningImage
{
    #region Variables

    public Int32 product_id;

    #endregion

    #region Constructors

    /// <summary>
    /// Create a new spinning image with default properties
    /// </summary>
    public SpinningImage()
    {
        // Set values for instance variables
        this.product_id = 0;

    } // End of the constructor

    /// <summary>
    /// Create a new spinning image from a reader
    /// </summary>
    /// <param name="reader"></param>
    public SpinningImage(MySqlDataReader reader)
    {
        // Set values for instance variables
        this.product_id = Convert.ToInt32(reader["product_id"]);

    } // End of the constructor

    #endregion

    #region Insert methods

    /// <summary>
    /// Add one spinning image
    /// </summary>
    /// <param name="post">A reference to a spinning image</param>
    public static long Add(SpinningImage post)
    {
        // Create the long to return
        long idOfInsert = 0;

        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "INSERT INTO spinning_images (product_id) VALUES (@product_id)";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {

                // Add parameters
                cmd.Parameters.AddWithValue("@product_id", post.product_id);

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases
                try
                {
                    // Open the connection
                    cn.Open();

                    // Execute the insert
                    cmd.ExecuteNonQuery();
                    idOfInsert = cmd.LastInsertedId;

                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
            }
        }

        // Return the id of the inserted item
        return idOfInsert;

    } // End of the Add method

    #endregion

    #region Get methods
    
    /// <summary>
    /// Get a list of all spinning images
    /// </summary>
    /// <returns>A list of spinning image posts</returns>
    public static List<SpinningImage> GetAll()
    {
        // Create the list to return
        List<SpinningImage> posts = new List<SpinningImage>();

        // Create the connection string and the sql statement. Limit with two arguments, 
        // the first argument specifies the offset of the first row to return, and the second specifies the 
        // maximum number of rows to return. The offset of the initial row is 0 (not 1).
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT * FROM spinning_images ORDER BY product_id ASC";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The using block is used to call dispose automatically even if there is a exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Create a MySqlDataReader
                MySqlDataReader reader = null;

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Fill the reader with data from the select command.
                    reader = cmd.ExecuteReader();

                    // Loop through the reader as long as there is something to read.
                    while (reader.Read())
                    {
                        posts.Add(new SpinningImage(reader));
                    }
                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
                finally
                {
                    // Call Close when done reading to avoid memory leakage.
                    if (reader != null)
                        reader.Close();
                }
            }
        }

        // Return the list of posts
        return posts;

    } // End of the GetAll method

    /// <summary>
    /// Get one spinning image on the product id
    /// </summary>
    /// <param name="id">A id</param>
    /// <returns>A reference to a spinning image post</returns>
    public static SpinningImage GetOneById(Int32 productId)
    {
        // Create the post to return
        SpinningImage post = null;

        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT * FROM spinning_images WHERE product_id = @product_id LIMIT 1";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Add a parameters
                cmd.Parameters.AddWithValue("@product_id", productId);

                // Create a MySqlDataReader
                MySqlDataReader reader = null;

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Fill the reader with one row of data.
                    reader = cmd.ExecuteReader();

                    // Loop through the reader as long as there is something to read and add values
                    while (reader.Read())
                    {
                        post = new SpinningImage(reader);
                    }
                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
                finally
                {
                    // Call Close when done reading to avoid memory leakage.
                    if (reader != null)
                        reader.Close();
                }
            }
        }

        // Return the post
        return post;

    } // End of the GetOneById method

    #endregion

    #region Delete methods

    /// <summary>
    /// Delete a spinning image on id
    /// </summary>
    /// <param name="id">The product id</param>
    public static void DeleteOnId(Int32 productId)
    {
        // Create the connection and the sql statement
        string connection = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "DELETE FROM spinning_images WHERE product_id = @product_id";

        // The using block is used to call dispose automatically even if there are an exception.
        using (MySqlConnection cn = new MySqlConnection(connection))
        {
            // The Using block is used to call dispose automatically even if there are an exception.
            using (MySqlCommand cmd = new MySqlCommand(sql, cn))
            {
                // Add parameters
                cmd.Parameters.AddWithValue("@product_id", productId);

                // The Try/Catch/Finally statement is used to handle unusual exceptions in the code to
                // avoid having our application crash in such cases.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Execute the update
                    cmd.ExecuteNonQuery();

                }
                catch (Exception e)
                {
                    string exceptionMessage = "";
                    if (HttpContext.Current.IsDebuggingEnabled)
                        throw e;
                    else
                        exceptionMessage = e.Message;
                }
            }
        }

    } // End of the DeleteOnId method

    #endregion

} // End of the class