﻿/// <reference path="jquery-1.10.2.min.js" />
/// <reference path="jquery-ui.min.js" />
/// <reference path="perfect-scrollbar-0.4.5.min.js" />

// Initialize when the form is loaded
$(document).ready(start);

// Start this instance
function start() 
{
    // Register events
    $(document).on("click", ".annytab-imap-show-imagemap", showMapContainer);
    $(document).on("click", "#annytabImapCloseContainer", closeMapContainer);
    $(document).on("click", ".annytab-imap-imagemap-button", loadImageMap);
    $(document).on("click", ".annytab-imap-imagemap-point", showMessageBox);
    $(document).on("click", ".annytab-imap-close", closeMessageBox);
    $("#annytabImapMapcontainer").perfectScrollbar();
    $("#annytabImapProductlistcontainer").perfectScrollbar();
    //$("#selectImageMapsContainer").perfectScrollbar({ useBothWheelAxes: true });
    $("#annytabImapOuterContainer").on("click", "#annytabImapLeftArrow", hoverScrollToLeft);
    $("#annytabImapOuterContainer").on("click", "#annytabImapRightArrow", hoverScrollToRight);

} // End of the start method

// Show the map container
function showMapContainer() {

    // Hide all the images
    $("#annytabImapSelectImage").find(".annytab-imap-imagemap-button").css("display", "none");

    // Get the category for the button click
    var category = $(this).attr("data-category");
    var name = $(this).attr("data-name");

    // Get the map container
    var mapContainer = $("#annytabImapOuterContainer");

    // Show all the images with the selected category id
    $("#annytabImapSelectImage").find("[data-category='" + category + "']").css("display", "inline-block");

    // Set the first image for the container
    $("#annytabImapSelectImage").find("[data-category='" + category + "']").first().click();

    // Set the header text
    $("#annytabImapHeader").text(name);

    // Show the map container
    mapContainer.fadeIn(1000);

} // End of the showMapContainer method

// Close the map container
function closeMapContainer() 
{
    // Get the map container
    var mapContainer = $("#annytabImapOuterContainer");

    // Close the map container
    mapContainer.fadeOut(1000);

} // End of the closeMapContainer method

function showMessageBox(event) 
{

    // Get the image map
    var imageMap = $("#annytabImapImagemap");

    // Close all the message boxes in the map
    imageMap.find(".annytab-imap-messagebox").hide();

    // Get the image map point
    var imageMapPoint = $(this);

    // Get the message box
    var messageBox = imageMapPoint.find(".annytab-imap-messagebox");

    // Get the x and y value
    var x = parseInt(imageMapPoint.css("left").replace("px", ""));
    var y = parseInt(imageMapPoint.css("top").replace("px", ""));

    // Get the max borders of the image
    var xMax = parseInt(imageMap.css("width").replace("px", ""));
    var yMax = parseInt(imageMap.css("height").replace("px", ""));

    // Set standard values for position
    messageBox.css("top", "0px");
    messageBox.css("left", "0px");
    messageBox.css("bottom", "auto");
    messageBox.css("right", "auto");

    // Get the image map container and set standard values for scroll
    var imageMapContainer = $("#annytabImapMapcontainer");
    
    // Make sure that the box is inside the div
    if ((x - 220) < 0) {
        messageBox.css("left", "0px");
    }
    if ((x + 220) > xMax) {
        messageBox.css("right", "0");
        messageBox.css("left", "auto");
    }
    if ((y - 110) < 0) {
        messageBox.css("top", "0px");
    }
    if ((y + 110) > yMax) {
        messageBox.css("bottom", "0px");
        messageBox.css("top", "auto");
    }

    // Scroll to the message box
    imageMapContainer.scrollTop(imageMapPoint.offset().top - imageMapContainer.offset().top + imageMapContainer.scrollTop() - 10);
    imageMapContainer.scrollLeft(imageMapPoint.offset().left - imageMapContainer.offset().left + imageMapContainer.scrollLeft() - 10);
    imageMapContainer.perfectScrollbar('update');

    // Show the message box
    messageBox.effect("shake", 500);
    //messageBox.css("display", "block");

    // Highlight the product in the products container
    var productContainer = $("#annytabImapProductlistcontainer");
    var product = productContainer.find("[data-id='" + messageBox.attr("data-artId") + "']");
    product.effect("highlight", { color: 'red' }, 1000);
    productContainer.scrollTop(product.offset().top - productContainer.offset().top + productContainer.scrollTop() - 10);

} // End of the showMessageBox method

// Close the message box
function closeMessageBox(event) 
{
    event.stopPropagation();
    var messageBox = $(this).closest("div");
    messageBox.effect("drop", { direction: "down" }, 1000);
    //$(this).closest("div").css("display", "none");
    
} // End of the closeMessageBox method

// Load the image map
function loadImageMap() 
{
    // Get the image map container
    var imageMapContainer = $("#annytabImapMapcontainer");

    // Get the image map
    var imageMap = $("#annytabImapImagemap");

    // Get the products container
    var productsContainer = $("#annytabImapProductlistcontainer");

    // Remove all the image map points in the image map
    imageMap.find(".annytab-imap-imagemap-point").remove();

    // Remove all the product posts in the products container
    productsContainer.find(".annytab-imap-productpost").remove();
    
    // Get information from the clicked image
    var dataString = $(this).data("points");

    // Get the main data
    var mainData = dataString.split("|");

    // Get the image map data
    var imageMapData = mainData[0].split(",");
    
    // Get point data
    var pointData = mainData[1].split(";");

    // Set the main image with effects
    imageMap.effect("drop", 500, function () {
        imageMap.css("background-image", "url('" + imageMapData[0] + "')");
        imageMap.css("width", imageMapData[1]);
        imageMap.css("height", imageMapData[2]);
    }).effect("slide", 500);

    // Add effects to the products
    productsContainer.effect("blind", 500, function () {
    }).effect("slide", 500);
    
    // Reset the scroll to the top left corner
    imageMapContainer.scrollTop("0");
    imageMapContainer.scrollLeft("0");
    imageMapContainer.perfectScrollbar('update');

    // Make sure that there is points
    if (pointData[0] == "")
        return;

    // Create image points <img src='images/circle.png' />
    for(var i = 0; i < pointData.length; i++) {

        // Get the map point data
        var mapPoint = pointData[i].split(","); // id, name, price, image, link, x, y

        // Create the image point
        var messageBox = "<div data-artId='" + mapPoint[0] + "' class='annytab-imap-messagebox'><img class='annytab-imap-close' src='images/blackCross.png' alt='Stäng' style='position:absolute;width:20px;height:20px;top:-5px;right:-5px;cursor:pointer;' />"
        + "<div class='annytab-imap-messageboxheading'>" + mapPoint[1] + "</div>" + "<div class='annytab-imap-pricetag'>Price: Fr. " + mapPoint[2] + "&#58;&#45;</div>" + "<a class='annytab-imap-boxbutton' href='" + mapPoint[4] + "'>Show product</a>" + "</div>";
        var controlText = "<div class='annytab-imap-imagemap-point' style='left:" + mapPoint[5] + ";top:" + mapPoint[6] + ";'><img class='annytab-imap-circlebutton' src='images/bluePoint.png' />" + messageBox + "</div>";

        // Add the image map point
        imageMap.append(controlText);

        // Create the product image
        if (productsContainer.find("[data-id='" + mapPoint[0] + "']").length == 0)
        {
            var productDiv = "<div class='annytab-imap-productpost' data-id='" + mapPoint[0] + "'><div class='annytab-imap-productheading'>" + mapPoint[1] + "</div><img class='annytab-imap-productimage' alt='" + mapPoint[1] + "' src='"
            + mapPoint[3] + "' /><br />" + "<div class='annytab-imap-pricetag'>Price: Fr. " + mapPoint[2] + "&#58;&#45;</div>" + "<a href='" + mapPoint[4] + "' class='annytab-imap-productbutton'>Show product</a>" + "</div><div style='clear:both'></div>";

            // Add the product to the list
            productsContainer.append(productDiv);
        }
    }

} // End of the loadImageMap method

// Scroll to the left
function hoverScrollToLeft(event) 
{
    // Get the container to scroll
    var imageContainer = $("#annytabImapSelectImage");

    // Prevent default behaviour
    event.preventDefault();

    // Get the left scroll
    var leftScroll = imageContainer.scrollLeft();

    // Decrease the scrolling
    leftScroll -= 320;
    if (leftScroll < 0)
        leftScroll = 0;

    // Scroll to the left
    imageContainer.animate({scrollLeft: leftScroll}, { duration: 300, easing: 'swing' });

} // End of the hoverScrollLeft method

// Scroll to the right
function hoverScrollToRight(event) 
{

    // Get the container to scroll
    var imageContainer = $("#annytabImapSelectImage");

    // Prevent default behaviour
    event.preventDefault();
    
    // Get the left scroll
    var leftScroll = imageContainer.scrollLeft();

    // Calculate the max scroll
    var maxScrollLeft = imageContainer.scrollWidth - imageContainer.clientWidth;

    // Increase the scrolling
    leftScroll += 320;
    if (leftScroll > maxScrollLeft)
        leftScroll = maxScrollLeft;

    // Scroll to the left
    imageContainer.animate({ scrollLeft: leftScroll }, { duration: 300, easing: 'swing' });
    //imageContainer.scrollLeft(leftScroll);

} // End of the hoverScrollRight method