﻿/// <reference path="jquery-1.10.2.min.js" />
/// <reference path="jquery-ui.js" />

// Variables
var isDragging = false;
var speed = 0.2;
var currentFloatImageIndex = 0;
var currentIntImageIndex = 0;
var previousMouseX = -1;

var imageArray;

var xCenter = 128;
var yCenter = 128;

// Initialize this script, when the document has been loaded
$(document).ready(start);

// Start this instance
function start() 
{
    // Register events
    $(".annytab-spin-show-image").on("click", showSpinningImage);
    $("#annytabSpinCloseContainer").on("click", hideSpinningImage);

    $("#annytabSpinImageContainer").on("mousedown touchstart", startSpinning);
    $("#annytabSpinImageContainer").on("mousemove touchmove", spinImage);
    $(document).on("mouseup touchend", stopSpinning);

    // On mousewheel event to zoom image
    $("#annytabSpinImageContainer").bind("mousewheel", zoomImage);

} // End of the start method

// Show the spinning image
function showSpinningImage() {

    // Get the image and the loading animation
    var loadingAnimation = $("#annytabSpinLoadingAnimation");
    var image = $("#annytabSpinImage");

    // Get the header and set the name
    var header = $("#annytabSpinHeader");
    header.html($(this).attr("data-name"));
    
    // Show the image
    $("#annytabSpinOuterContainer").fadeIn(100);

    // Get data from the button that was clicked
    var productId = $(this).attr("data-id");
    var imageData = $(this).attr("data-images");
    
    // Create the image array
    imageArray = imageData.split("|");

    // Preload images
    preload(imageArray);
    
    // Reset start values
    currentFloatImageIndex = 0;
    currentIntImageIndex = 0;

    // Set the start image
    image.attr("src", imageArray[currentIntImageIndex]);

    // Create the slider
    var maxValue = imageArray.length - 1;

    $("#annytabSpinSlider").slider({ step: 1, min: 0, max: maxValue, value: 0, slide: sliding });
    
    // Show the image and hide the loading animation
    $("#annytabSpinLoadingAnimation").fadeOut(1000);
    $("#annytabSpinImage").fadeIn(1000);

} // End of the showSpinningImage method

// Preload images
function preload(arrayOfImages) {

    // Get the image preload control
    var imagePreload = $("#annytabSpinImagePreloads");

    // Remove the images that are in the div
    imagePreload.find("img").remove();

    for(var i = 0; i < arrayOfImages.length; i++)
    {
        imagePreload.append("<img src='" + arrayOfImages[i] + "' />");
    }

} // End of the preload method

// Hide the spinning image
function hideSpinningImage() {

    $("#annytabSpinImage").fadeOut(1000);
    $("#annytabSpinLoadingAnimation").fadeIn(1000);
    $("#annytabSpinOuterContainer").fadeOut(1000);

} // End of the hideSpinningImage method

// Start spinning the image
function startSpinning(event) 
{

    // Prevent default behavior to get expected dragging behaviour
    event.preventDefault();

    if (isDragging == false) 
    {
        isDragging = true;
    }

} // End of the startSpinning method

// Spin the image
function spinImage(event) 
{
    // Check if the user is dragging
    if (isDragging == true) 
    {
        // Get the image container div and the image
        var container = $("#annytabSpinImageContainer");
        var image = $("#annytabSpinImage");

        // Get x and y values for the mouse movement
        var x = 0;
        var y = 0;

        if (event.type == 'touchmove') {

            x = event.originalEvent.targetTouches[0].pageX;
            y = event.originalEvent.targetTouches[0].pageY;
        }
        else 
        {
            x = event.pageX - container.offset().left;
            y = event.pageY - container.offset().top;
        }

        // Calculate the delta value for x
        var deltaX = 0;
        if (previousMouseX > -1) {

            // Calculate the drag direction
            if ((x - previousMouseX) > 0)
                deltaX = 1;
            else if ((x - previousMouseX) < 0)
                deltaX = -1;
            //deltaX = Math.max(-1, Math.min(1, (x - previousMouseX)));
            currentFloatImageIndex += deltaX * speed;
        }

        // Calculate the int value of the current float value
        currentIntImageIndex = Math.floor(currentFloatImageIndex);
        
        // Reset values when we have reached end points
        if (currentFloatImageIndex < 0) 
        {
            currentFloatImageIndex = imageArray.length - 1;
            currentIntImageIndex = imageArray.length - 1;
        }
        else if (currentFloatImageIndex > (imageArray.length - 1)) 
        {
            currentFloatImageIndex = 0;
            currentIntImageIndex = 0;
        }

        // Set the source of the image
        image.attr("src", imageArray[currentIntImageIndex]);
        
        // Set the value for the slider
        $("#annytabSpinSlider").slider("value", currentIntImageIndex);

        // Set the previous x coord for the mouse
        previousMouseX = x;
    }

} // End of the spinImage method

// Stop spinning the image
function stopSpinning() {

    if (isDragging == true) {

        isDragging = false;
        previousMouseX = -1;
    }
} // End of the stopSpinning method

// Handle the slide event
function sliding(event, ui) {

    // Get the image
    var image = $("#annytabSpinImage");

    // Get the slider
    var imageSlider = $("#annytabSpinSlider");

    // Set the current int index imageSlider.slider("value")
    currentFloatImageIndex = ui.value;
    currentIntImageIndex = ui.value;

    // Reset values when we have reached end points
    if (currentFloatImageIndex < 0) 
    {
        currentFloatImageIndex = imageArray.length - 1;
        currentIntImageIndex = imageArray.length - 1;
    }
    else if (currentFloatImageIndex > (imageArray.length - 1)) 
    {
        currentFloatImageIndex = 0;
        currentIntImageIndex = 0;
    }

    // Set the source of the image
    image.attr("src", imageArray[currentIntImageIndex]);

} // End of the sliding method

// Zoom the image
function zoomImage(event, delta) {

    
    // Get the image
    var image = $("#annytabSpinImage");

    // Get the div
    var div = $("#annytabSpinImageContainer");

    // Get x and y values for the mouse movement
    var x = event.pageX - image.offset().left;
    var y = event.pageY - image.offset().top;

    // Get the width and height for the image
    var widthValue = image.css("width").replace("px", "");
    var heightValue = image.css("height").replace("px", "");
    widthValue = parseFloat(widthValue);
    heightValue = parseFloat(heightValue);

    // Change the zoom
    if (delta > 0) // Forward movement
    {
        // Get the center point for the mouse
        xCenter = (event.pageX - div.offset().left);
        yCenter = (event.pageY - div.offset().top);
        widthValue += 128;
        heightValue += 128;
    }
    else if (delta < 0) 
    {
        // Get the center point for the mouse
        xCenter = (event.pageX - div.offset().left);
        yCenter = (event.pageY - div.offset().top);
        widthValue -= 128;
        heightValue -= 128;
    }

    // Adjust values to constrains
    if (widthValue < 256)
        widthValue = 256;
    if (heightValue < 256)
        heightValue = 256;
    if (widthValue > 768)
        widthValue = 768;
    if (heightValue > 768)
        heightValue = 768;

    // Calculate the scale
    var xScale = widthValue / 256;
    var yScale = heightValue / 256;

    // Calculate the center
    var xDiff = xCenter * xScale - xCenter;
    var yDiff = yCenter * yScale - yCenter;

    // Set the center of the image
    image.animate({ top: -yDiff + "px", left: -xDiff + "px", width: widthValue + "px", height: heightValue + "px" }, { queue: false, duration: 500, easing: 'swing' });

} // End of the zoomImage method
