﻿/// <reference path="jquery-1.10.2.min.js" />

// Variables
var movingImagePoint = null;

// Initialize when the form is loaded
$(document).ready(start);

// Start this instance
function start() 
{
    // Get the image map
    var imageMap = $("#annytabImapImageMap");

    // Register events
    $(document).on("click", "#annytabImapAddImagePoint", addImagePoint);
    $(".annytab-imap-imagemap-button").on("click", changeImageMap);
    imageMap.on("mousemove", moveImagePoint);
    imageMap.on("mousedown", ".annytab-imap-draggable", setImagePoint);
    imageMap.on("mouseup", removeImagePoint);
    imageMap.on("click", ".annytab-imap-delete", deleteImagePoint);
    $(document).on("click", "#annytabImapSaveImageMap", saveImageMap); 

} // End of the start method

// Add a image point
function addImagePoint(event) 
{
    // Get the image map
    var imageMap = $("#annytabImapImageMap");

    // Get x and y
    var x = event.pageX - imageMap.offset().left;
    var y = event.pageY - imageMap.offset().top;

    // Get the selected product
    var product = $("#annytabImapSelectProduct").find(":selected");

    // Create the message box
    var messageBox = "<div class='annytab-imap-admin-messagebox'><img class='annytab-imap-delete' src='images/blackCross.png' alt='Radera' style='position:absolute;width:20px;height:20px;top:-5px;right:-5px;cursor:pointer;' />"
        + "<div class='annytab-imap-messageboxheading'>" + product.text() + "</div></div>";

    // Add the image point to the imagemap
    var div = "<div data-product='" + product.val() + "' class='annytab-imap-admin-image-point'><img class='annytab-imap-draggable' src='images/bluePoint.png' />" + messageBox + "</div>";
    imageMap.append(div);

    // Scroll to the top
    $("#annytabImapMapContainer").scrollTop("0");
    $("#annytabImapMapContainer").scrollLeft("0");

} // End of the addImagePoint method

// Set the image point that is moving
function setImagePoint(event) 
{

    // Get the imagepoint
    var imagePoint = $(this);

    // Prevent default behavior to get expected drag behaviour
    event.preventDefault();

    // Move the image point if it is different from null
    if (movingImagePoint == null) 
    {
        movingImagePoint = imagePoint;
    }

} // End of the setImagePoint method

// Remove the image point
function removeImagePoint() 
{
    if(movingImagePoint != null)
        movingImagePoint = null;

} // End of the removeImagePoint method

// Move the image point
function moveImagePoint(event) 
{

    if (movingImagePoint != null) 
    {
        // Get the div for the image that caused the event
        var div = movingImagePoint.closest("div");

        // Get the imagemap
        var imageMap = $("#annytabImapImageMap");

        // Get the max borders of the image
        var xMax = parseInt(imageMap.css("width").replace("px", ""));

        // Get the message box
        var messageBox = div.find(".annytab-imap-admin-messagebox");

        // Get x and y
        var x = event.pageX - imageMap.offset().left - 8;
        var y = event.pageY - imageMap.offset().top - 8;

        // Adjust the message box
        messageBox.css("left", "28px");
        if ((x + 190) > xMax) 
        {
            messageBox.css("left", "-168px");
        }

        // Change the position of the div
        div.css("left", x + "px");
        div.css("top", y + "px");
    }

} // End of the moveImagePoint method

// Delete the image point
function deleteImagePoint() 
{

    // Get the image that caused the click
    var deleteButton = $(this);

    // Get the div to delete
    var div = deleteButton.closest(".annytab-imap-admin-image-point");

    // Remove the div
    div.remove();

} // End of the deleteImagePoint method

// Change the image map
function changeImageMap()
{
    // Get a reference to the image map
    var imageMap = $("#annytabImapImageMap");

    // Get the image that caused the click event
    var imageMapButton = $(this);

    // Get the image map data
    var imageMapData = imageMapButton.attr("data-file").split(",");

    // Change the background image
    $("#annytabImapHiddenImageMapUrl").val(imageMapData[0]);
    imageMap.css("background-image", "url('" + imageMapData[0] + "')");
    imageMap.css("width", imageMapData[1]);
    imageMap.css("height", imageMapData[2]);

} // End of the changeImageMap method

// Save the image map
function saveImageMap() 
{

    // Get a reference to the image map
    var imageMap = $("#annytabImapImageMap");

    // Get the category
    var category = $("#annytabImapSelectCategory").find(":selected");

    // Get the hidden image url value
    var imageUrl = $("#annytabImapHiddenImageMapUrl").val();

    // Make sure that there is a inspiration image
    if (imageUrl == "") 
    {
        var errorDiv = $("#divErrors");
        errorDiv.css("display", "inline-block");
        errorDiv.find(".annytab-imap-error-message").remove();
        errorDiv.append("<div class='annytab-imap-error-message' style='color:#ff0000;'>- You have not selected a image map!</div>");
        $(document).scrollTop(0);
        return;
    }
    
    // Make sure that a category is selected
    if(category.val() == "-1")
    {
        var errorDiv = $("#divErrors");
        errorDiv.css("display", "inline-block");
        errorDiv.find(".annytab-imap-error-message").remove();
        errorDiv.append("<div class='annytab-imap-error-message' style='color:#ff0000;'>- You have not selected a category!</div>");
        $(document).scrollTop(0);
        return;
    }

    // Get the image url
    var dataString = imageUrl + "|" + category.val() + "|";

    // Get all the draggable images
    var imagePoints = imageMap.find(".annytab-imap-draggable").closest("div");
    
    // Get the number of divs
    var numberOfDivs = imagePoints.length;

    // Get all the divs in the image map
    for (var i = 0; i < numberOfDivs; i++) 
    {
        // Get the closest div
        var div = $(imagePoints[i]);

        // Get the data
        var productId = div.data("product");
        var xPosition = div.css("left");
        var yPosition = div.css("top");

        // Add the data to the image points string
        dataString += productId + "," + xPosition + "," + yPosition;

        if (i != (numberOfDivs - 1)) {
            dataString += ";";
        }
    }

    // Post the data
    $.ajax({
        type: "POST",
        url: "AdminNewImageMap.aspx/SaveImageMap",
        data: "{'dataString': '" + dataString + "'}",
        contentType: "application/json; charset=utf-8",
        dataType: "json",
        success: function(data) {
            window.location.href = "AdminNewImageMap.aspx";
        },
    });

} // End of the saveImageMap method